This is a **autocomplete widget** for for `YAFOWIL
<http://pypi.python.org/pypi/yafowil>`_ - Yet Another Form WIdget Library.

It utilizes/integrates `jquery.ui.autocomplete
<http://docs.jquery.com/UI/Autocomplete>`_ for/in YAFOWIL providing an
autocomplete function on a text input.

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#autocomplete>`_
- `DEMO - see it Live <http://docs.demo.yafowil.info/++widget++yafowil.widget.autocomplete/index.html>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.autocomplete>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Jens Klein <jens@bluedynamics.com>
